summaryrefslogtreecommitdiffstats
path: root/languages/cpp/app_templates
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/app_templates')
-rw-r--r--languages/cpp/app_templates/cmakeqt3app/cmakeqt3app.cpp26
-rw-r--r--languages/cpp/app_templates/cmakeqt3app/main.cpp2
-rw-r--r--languages/cpp/app_templates/kapp/app.cpp24
-rw-r--r--languages/cpp/app_templates/kapp/appview.cpp8
-rw-r--r--languages/cpp/app_templates/kateplugin/plugin_app.cpp2
-rw-r--r--languages/cpp/app_templates/kateplugin2/plugin_app.cpp6
-rw-r--r--languages/cpp/app_templates/kdevlang/kdevlang_part.cpp26
-rw-r--r--languages/cpp/app_templates/kdevpart/kdevpart_part.cpp22
-rw-r--r--languages/cpp/app_templates/kdevpart2/kdevpart_part.cpp22
-rw-r--r--languages/cpp/app_templates/kofficepart/kopart_view.cpp4
-rw-r--r--languages/cpp/app_templates/kpartapp/app.cpp18
-rw-r--r--languages/cpp/app_templates/kpartapp/app_part.cpp14
-rw-r--r--languages/cpp/app_templates/kpartplugin/plugin_app.cpp2
-rw-r--r--languages/cpp/app_templates/kscons_kxt/app.cpp28
-rw-r--r--languages/cpp/app_templates/kscons_tdemdi/app_part.cpp14
-rw-r--r--languages/cpp/app_templates/kscons_tdemdi/apptdemdi.cpp28
-rw-r--r--languages/cpp/app_templates/kscons_tdemdi/apptdemdiView.cpp2
-rw-r--r--languages/cpp/app_templates/kscons_tdemdi/tdemdikonsole.cpp2
-rw-r--r--languages/cpp/app_templates/kxt/app.cpp26
-rw-r--r--languages/cpp/app_templates/noatunui/plugin_impl.cpp42
-rw-r--r--languages/cpp/app_templates/opieapp/example.cpp2
-rw-r--r--languages/cpp/app_templates/opieinput/simpleimpl.cpp24
-rw-r--r--languages/cpp/app_templates/opietoday/examplepluginwidget.cpp2
-rw-r--r--languages/cpp/app_templates/qmakeapp/main.cpp2
-rw-r--r--languages/cpp/app_templates/qmakeapp/qmakeapp.cpp26
-rw-r--r--languages/cpp/app_templates/qtopiaapp/example.cpp2
-rw-r--r--languages/cpp/app_templates/tdeconfig35/app.cpp18
-rw-r--r--languages/cpp/app_templates/tdescreensaver/tdescreensaver.cpp8
28 files changed, 201 insertions, 201 deletions
diff --git a/languages/cpp/app_templates/cmakeqt3app/cmakeqt3app.cpp b/languages/cpp/app_templates/cmakeqt3app/cmakeqt3app.cpp
index 39b6e5af..8ce81310 100644
--- a/languages/cpp/app_templates/cmakeqt3app/cmakeqt3app.cpp
+++ b/languages/cpp/app_templates/cmakeqt3app/cmakeqt3app.cpp
@@ -37,17 +37,17 @@
openIcon = TQPixmap( fileopen );
TQToolButton * fileOpen
= new TQToolButton( openIcon, tr("Open File"), TQString(),
- this, TQT_SLOT(choose()), fileTools, "open file" );
+ this, TQ_SLOT(choose()), fileTools, "open file" );
saveIcon = TQPixmap( filesave );
TQToolButton * fileSave
= new TQToolButton( saveIcon, tr("Save File"), TQString(),
- this, TQT_SLOT(save()), fileTools, "save file" );
+ this, TQ_SLOT(save()), fileTools, "save file" );
printIcon = TQPixmap( fileprint );
TQToolButton * filePrint
= new TQToolButton( printIcon, tr("Print File"), TQString(),
- this, TQT_SLOT(print()), fileTools, "print file" );
+ this, TQ_SLOT(print()), fileTools, "print file" );
(void)TQWhatsThis::whatsThisButton( fileTools );
@@ -79,41 +79,41 @@
menuBar()->insertItem( tr("&File"), file );
- file->insertItem( tr("&New"), this, TQT_SLOT(newDoc()), CTRL+Key_N );
+ file->insertItem( tr("&New"), this, TQ_SLOT(newDoc()), CTRL+Key_N );
int id;
id = file->insertItem( openIcon, tr("&Open..."),
- this, TQT_SLOT(choose()), CTRL+Key_O );
+ this, TQ_SLOT(choose()), CTRL+Key_O );
file->setWhatsThis( id, fileOpenText );
id = file->insertItem( saveIcon, tr("&Save"),
- this, TQT_SLOT(save()), CTRL+Key_S );
+ this, TQ_SLOT(save()), CTRL+Key_S );
file->setWhatsThis( id, fileSaveText );
- id = file->insertItem( tr("Save &As..."), this, TQT_SLOT(saveAs()) );
+ id = file->insertItem( tr("Save &As..."), this, TQ_SLOT(saveAs()) );
file->setWhatsThis( id, fileSaveText );
file->insertSeparator();
id = file->insertItem( printIcon, tr("&Print..."),
- this, TQT_SLOT(print()), CTRL+Key_P );
+ this, TQ_SLOT(print()), CTRL+Key_P );
file->setWhatsThis( id, filePrintText );
file->insertSeparator();
- file->insertItem( tr("&Close"), this, TQT_SLOT(close()), CTRL+Key_W );
+ file->insertItem( tr("&Close"), this, TQ_SLOT(close()), CTRL+Key_W );
- file->insertItem( tr("&Quit"), tqApp, TQT_SLOT( closeAllWindows() ), CTRL+Key_Q );
+ file->insertItem( tr("&Quit"), tqApp, TQ_SLOT( closeAllWindows() ), CTRL+Key_Q );
menuBar()->insertSeparator();
TQPopupMenu * help = new TQPopupMenu( this );
menuBar()->insertItem( tr("&Help"), help );
- help->insertItem( tr("&About"), this, TQT_SLOT(about()), Key_F1 );
- help->insertItem( tr("About &TQt"), this, TQT_SLOT(aboutTQt()) );
+ help->insertItem( tr("&About"), this, TQ_SLOT(about()), Key_F1 );
+ help->insertItem( tr("About &TQt"), this, TQ_SLOT(aboutTQt()) );
help->insertSeparator();
- help->insertItem( tr("What's &This"), this, TQT_SLOT(whatsThis()), SHIFT+Key_F1 );
+ help->insertItem( tr("What's &This"), this, TQ_SLOT(whatsThis()), SHIFT+Key_F1 );
e = new TQTextEdit( this, "editor" );
e->setFocus();
diff --git a/languages/cpp/app_templates/cmakeqt3app/main.cpp b/languages/cpp/app_templates/cmakeqt3app/main.cpp
index 8938adc5..ba45c728 100644
--- a/languages/cpp/app_templates/cmakeqt3app/main.cpp
+++ b/languages/cpp/app_templates/cmakeqt3app/main.cpp
@@ -8,6 +8,6 @@ int main( int argc, char ** argv ) {
%{APPNAME} * mw = new %{APPNAME}();
mw->setCaption( "%{APPNAME}" );
mw->show();
- a.connect( &a, TQT_SIGNAL(lastWindowClosed()), &a, TQT_SLOT(quit()) );
+ a.connect( &a, TQ_SIGNAL(lastWindowClosed()), &a, TQ_SLOT(quit()) );
return a.exec();
}
diff --git a/languages/cpp/app_templates/kapp/app.cpp b/languages/cpp/app_templates/kapp/app.cpp
index 774efe8e..d801904f 100644
--- a/languages/cpp/app_templates/kapp/app.cpp
+++ b/languages/cpp/app_templates/kapp/app.cpp
@@ -49,10 +49,10 @@
setupGUI();
// allow the view to change the statusbar and caption
- connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
- this, TQT_SLOT(changeStatusbar(const TQString&)));
- connect(m_view, TQT_SIGNAL(signalChangeCaption(const TQString&)),
- this, TQT_SLOT(changeCaption(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeStatusbar(const TQString&)),
+ this, TQ_SLOT(changeStatusbar(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeCaption(const TQString&)),
+ this, TQ_SLOT(changeCaption(const TQString&)));
}
@@ -88,19 +88,19 @@ void %{APPNAME}::load(const KURL& url)
void %{APPNAME}::setupActions()
{
- KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
- KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
- KStdAction::save(this, TQT_SLOT(fileSave()), actionCollection());
- KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
- KStdAction::print(this, TQT_SLOT(filePrint()), actionCollection());
- KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+ KStdAction::openNew(this, TQ_SLOT(fileNew()), actionCollection());
+ KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
+ KStdAction::save(this, TQ_SLOT(fileSave()), actionCollection());
+ KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+ KStdAction::print(this, TQ_SLOT(filePrint()), actionCollection());
+ KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
- KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+ KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
// this doesn't do anything useful. it's just here to illustrate
// how to insert a custom menu and menu item
TDEAction *custom = new TDEAction(i18n("Cus&tom Menuitem"), 0,
- this, TQT_SLOT(optionsPreferences()),
+ this, TQ_SLOT(optionsPreferences()),
actionCollection(), "custom_action");
}
diff --git a/languages/cpp/app_templates/kapp/appview.cpp b/languages/cpp/app_templates/kapp/appview.cpp
index 16c05a3f..244f4a75 100644
--- a/languages/cpp/app_templates/kapp/appview.cpp
+++ b/languages/cpp/app_templates/kapp/appview.cpp
@@ -63,10 +63,10 @@
return;
}
- connect(m_html, TQT_SIGNAL(setWindowCaption(const TQString&)),
- this, TQT_SLOT(slotSetTitle(const TQString&)));
- connect(m_html, TQT_SIGNAL(setStatusBarText(const TQString&)),
- this, TQT_SLOT(slotOnURL(const TQString&)));
+ connect(m_html, TQ_SIGNAL(setWindowCaption(const TQString&)),
+ this, TQ_SLOT(slotSetTitle(const TQString&)));
+ connect(m_html, TQ_SIGNAL(setStatusBarText(const TQString&)),
+ this, TQ_SLOT(slotOnURL(const TQString&)));
}
diff --git a/languages/cpp/app_templates/kateplugin/plugin_app.cpp b/languages/cpp/app_templates/kateplugin/plugin_app.cpp
index 4d80a74c..351fca4e 100644
--- a/languages/cpp/app_templates/kateplugin/plugin_app.cpp
+++ b/languages/cpp/app_templates/kateplugin/plugin_app.cpp
@@ -55,7 +55,7 @@ void KatePlugin%{APPNAME}::addView(Kate::MainWindow *win)
PluginView *view = new PluginView ();
(void) new TDEAction ( i18n("Insert Hello World"), 0, this,
- TQT_SLOT( slotInsertHello() ), view->actionCollection(),
+ TQ_SLOT( slotInsertHello() ), view->actionCollection(),
"edit_insert_%{APPNAMELC}" );
view->setInstance (new TDEInstance("kate"));
diff --git a/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp b/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
index 69dcd7d8..c96ffbf1 100644
--- a/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
+++ b/languages/cpp/app_templates/kdevlang/kdevlang_part.cpp
@@ -28,17 +28,17 @@ static const KDevPluginInfo data("kdev%{APPNAMELC}");
setXMLFile("kdevlang_%{APPNAMELC}.rc");
- m_build = new TDEAction( i18n("&Run"), "application-x-executable",Key_F9,this, TQT_SLOT(slotRun()),actionCollection(), "build_execute" );
+ m_build = new TDEAction( i18n("&Run"), "application-x-executable",Key_F9,this, TQ_SLOT(slotRun()),actionCollection(), "build_execute" );
kdDebug() << "Creating %{APPNAMELC} Part" << endl;
- connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)),
- this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
- connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()) );
- connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()) );
- connect( partController(), TQT_SIGNAL(savedFile(const KURL&)), this, TQT_SLOT(savedFile(const KURL&)) );
- connect(partController(), TQT_SIGNAL(activePartChanged(KParts::Part*)),
- this, TQT_SLOT(slotActivePartChanged(KParts::Part *)));
+ connect( core(), TQ_SIGNAL(projectConfigWidget(KDialogBase*)),
+ this, TQ_SLOT(projectConfigWidget(KDialogBase*)) );
+ connect( core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()) );
+ connect( core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()) );
+ connect( partController(), TQ_SIGNAL(savedFile(const KURL&)), this, TQ_SLOT(savedFile(const KURL&)) );
+ connect(partController(), TQ_SIGNAL(activePartChanged(KParts::Part*)),
+ this, TQ_SLOT(slotActivePartChanged(KParts::Part *)));
}
@@ -74,14 +74,14 @@ void %{APPNAME}Part::projectOpened()
{
kdDebug(9014) << "projectOpened()" << endl;
- connect( project(), TQT_SIGNAL(addedFilesToProject(const TQStringList &)),
- this, TQT_SLOT(addedFilesToProject(const TQStringList &)) );
- connect( project(), TQT_SIGNAL(removedFilesFromProject(const TQStringList &)),
- this, TQT_SLOT(removedFilesFromProject(const TQStringList &)) );
+ connect( project(), TQ_SIGNAL(addedFilesToProject(const TQStringList &)),
+ this, TQ_SLOT(addedFilesToProject(const TQStringList &)) );
+ connect( project(), TQ_SIGNAL(removedFilesFromProject(const TQStringList &)),
+ this, TQ_SLOT(removedFilesFromProject(const TQStringList &)) );
// We want to parse only after all components have been
// properly initialized
- TQTimer::singleShot(0, this, TQT_SLOT(parse()));
+ TQTimer::singleShot(0, this, TQ_SLOT(parse()));
}
void %{APPNAME}Part::projectClosed()
{
diff --git a/languages/cpp/app_templates/kdevpart/kdevpart_part.cpp b/languages/cpp/app_templates/kdevpart/kdevpart_part.cpp
index 6a2559ba..4c940738 100644
--- a/languages/cpp/app_templates/kdevpart/kdevpart_part.cpp
+++ b/languages/cpp/app_templates/kdevpart/kdevpart_part.cpp
@@ -60,16 +60,16 @@ K_EXPORT_COMPONENT_FACTORY( libkdev%{APPNAMELC}, %{APPNAME}Factory( pluginData )
m_configProxy = new ConfigWidgetProxy(core());
m_configProxy->createGlobalConfigPage(i18n("%{APPNAME}"), GLOBALDOC_OPTIONS, info()->icon());
m_configProxy->createProjectConfigPage(i18n("%{APPNAME}"), PROJECTDOC_OPTIONS, info()->icon());
- connect(m_configProxy, TQT_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
- this, TQT_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int)));
+ connect(m_configProxy, TQ_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
+ this, TQ_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int)));
- connect(core(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
- this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)));
- connect(core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()));
- connect(core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()));
+ connect(core(), TQ_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
+ this, TQ_SLOT(contextMenu(TQPopupMenu *, const Context *)));
+ connect(core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()));
+ connect(core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()));
- TQTimer::singleShot(0, this, TQT_SLOT(init()));
+ TQTimer::singleShot(0, this, TQ_SLOT(init()));
}
%{APPNAME}Part::~%{APPNAME}Part()
@@ -92,7 +92,7 @@ void %{APPNAME}Part::setupActions()
{
// create XMLGUI actions here
action = new TDEAction(i18n("&Do Something..."), 0,
- this, TQT_SLOT(doSomething()), actionCollection(), "plugin_action" );
+ this, TQ_SLOT(doSomething()), actionCollection(), "plugin_action" );
action->setToolTip(i18n("Do something"));
action->setWhatsThis(i18n("<b>Do something</b><p>Describe here what does this action do."));
}
@@ -105,13 +105,13 @@ void %{APPNAME}Part::insertConfigWidget(const KDialogBase *dlg, TQWidget *page,
case GLOBALDOC_OPTIONS:
{
%{APPNAME}GlobalConfig *w = new %{APPNAME}GlobalConfig(this, page, "global config");
- connect(dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()));
+ connect(dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()));
break;
}
case PROJECTDOC_OPTIONS:
{
%{APPNAME}ProjectConfig *w = new %{APPNAME}ProjectConfig(this, page, "project config");
- connect(dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()));
+ connect(dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()));
break;
}
}
@@ -131,7 +131,7 @@ void %{APPNAME}Part::contextMenu(TQPopupMenu *popup, const Context *context)
// or create menu items on the fly
// int id = -1;
// id = popup->insertItem(i18n("Do Something Here"),
- // this, TQT_SLOT(doSomething()) );
+ // this, TQ_SLOT(doSomething()) );
// popup->setWhatsThis(id, i18n("<b>Do something here</b><p>Describe here what does this action do."
}
else if (context->hasType(Context::FileContext))
diff --git a/languages/cpp/app_templates/kdevpart2/kdevpart_part.cpp b/languages/cpp/app_templates/kdevpart2/kdevpart_part.cpp
index 6a2559ba..4c940738 100644
--- a/languages/cpp/app_templates/kdevpart2/kdevpart_part.cpp
+++ b/languages/cpp/app_templates/kdevpart2/kdevpart_part.cpp
@@ -60,16 +60,16 @@ K_EXPORT_COMPONENT_FACTORY( libkdev%{APPNAMELC}, %{APPNAME}Factory( pluginData )
m_configProxy = new ConfigWidgetProxy(core());
m_configProxy->createGlobalConfigPage(i18n("%{APPNAME}"), GLOBALDOC_OPTIONS, info()->icon());
m_configProxy->createProjectConfigPage(i18n("%{APPNAME}"), PROJECTDOC_OPTIONS, info()->icon());
- connect(m_configProxy, TQT_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
- this, TQT_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int)));
+ connect(m_configProxy, TQ_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
+ this, TQ_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int)));
- connect(core(), TQT_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
- this, TQT_SLOT(contextMenu(TQPopupMenu *, const Context *)));
- connect(core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(projectOpened()));
- connect(core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(projectClosed()));
+ connect(core(), TQ_SIGNAL(contextMenu(TQPopupMenu *, const Context *)),
+ this, TQ_SLOT(contextMenu(TQPopupMenu *, const Context *)));
+ connect(core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(projectOpened()));
+ connect(core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(projectClosed()));
- TQTimer::singleShot(0, this, TQT_SLOT(init()));
+ TQTimer::singleShot(0, this, TQ_SLOT(init()));
}
%{APPNAME}Part::~%{APPNAME}Part()
@@ -92,7 +92,7 @@ void %{APPNAME}Part::setupActions()
{
// create XMLGUI actions here
action = new TDEAction(i18n("&Do Something..."), 0,
- this, TQT_SLOT(doSomething()), actionCollection(), "plugin_action" );
+ this, TQ_SLOT(doSomething()), actionCollection(), "plugin_action" );
action->setToolTip(i18n("Do something"));
action->setWhatsThis(i18n("<b>Do something</b><p>Describe here what does this action do."));
}
@@ -105,13 +105,13 @@ void %{APPNAME}Part::insertConfigWidget(const KDialogBase *dlg, TQWidget *page,
case GLOBALDOC_OPTIONS:
{
%{APPNAME}GlobalConfig *w = new %{APPNAME}GlobalConfig(this, page, "global config");
- connect(dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()));
+ connect(dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()));
break;
}
case PROJECTDOC_OPTIONS:
{
%{APPNAME}ProjectConfig *w = new %{APPNAME}ProjectConfig(this, page, "project config");
- connect(dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()));
+ connect(dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()));
break;
}
}
@@ -131,7 +131,7 @@ void %{APPNAME}Part::contextMenu(TQPopupMenu *popup, const Context *context)
// or create menu items on the fly
// int id = -1;
// id = popup->insertItem(i18n("Do Something Here"),
- // this, TQT_SLOT(doSomething()) );
+ // this, TQ_SLOT(doSomething()) );
// popup->setWhatsThis(id, i18n("<b>Do something here</b><p>Describe here what does this action do."
}
else if (context->hasType(Context::FileContext))
diff --git a/languages/cpp/app_templates/kofficepart/kopart_view.cpp b/languages/cpp/app_templates/kofficepart/kopart_view.cpp
index 601413ef..2cf5ff06 100644
--- a/languages/cpp/app_templates/kofficepart/kopart_view.cpp
+++ b/languages/cpp/app_templates/kofficepart/kopart_view.cpp
@@ -18,9 +18,9 @@
{
setInstance( %{APPNAME}Factory::global() );
setXMLFile( "%{APPNAMELC}.rc" );
- KStdAction::cut(this, TQT_SLOT( cut() ), actionCollection(), "cut" );
+ KStdAction::cut(this, TQ_SLOT( cut() ), actionCollection(), "cut" );
// Note: Prefer KStdAction::* to any custom action if possible.
- //m_cut = new TDEAction( i18n("&Cut"), "edit-cut", 0, this, TQT_SLOT( cut() ),
+ //m_cut = new TDEAction( i18n("&Cut"), "edit-cut", 0, this, TQ_SLOT( cut() ),
// actionCollection(), "cut");
}
diff --git a/languages/cpp/app_templates/kpartapp/app.cpp b/languages/cpp/app_templates/kpartapp/app.cpp
index 759cbf5a..f963714e 100644
--- a/languages/cpp/app_templates/kpartapp/app.cpp
+++ b/languages/cpp/app_templates/kpartapp/app.cpp
@@ -76,16 +76,16 @@ void %{APPNAME}::load(const KURL& url)
void %{APPNAME}::setupActions()
{
- KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
- KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
+ KStdAction::openNew(this, TQ_SLOT(fileNew()), actionCollection());
+ KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
- KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+ KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
- m_toolbarAction = KStdAction::showToolbar(this, TQT_SLOT(optionsShowToolbar()), actionCollection());
- m_statusbarAction = KStdAction::showStatusbar(this, TQT_SLOT(optionsShowStatusbar()), actionCollection());
+ m_toolbarAction = KStdAction::showToolbar(this, TQ_SLOT(optionsShowToolbar()), actionCollection());
+ m_statusbarAction = KStdAction::showStatusbar(this, TQ_SLOT(optionsShowStatusbar()), actionCollection());
- KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
- KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
+ KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+ KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
}
void %{APPNAME}::saveProperties(TDEConfig* /*config*/)
@@ -159,8 +159,8 @@ void %{APPNAME}::optionsConfigureToolbars()
// use the standard toolbar editor
KEditToolbar dlg(factory());
- connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
- this, TQT_SLOT(applyNewToolbarConfig()));
+ connect(&dlg, TQ_SIGNAL(newToolbarConfig()),
+ this, TQ_SLOT(applyNewToolbarConfig()));
dlg.exec();
}
diff --git a/languages/cpp/app_templates/kpartapp/app_part.cpp b/languages/cpp/app_templates/kpartapp/app_part.cpp
index adf210b3..f4f866b1 100644
--- a/languages/cpp/app_templates/kpartapp/app_part.cpp
+++ b/languages/cpp/app_templates/kpartapp/app_part.cpp
@@ -26,9 +26,9 @@
setWidget(m_widget);
// create our actions
- KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
- KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
- KStdAction::save(this, TQT_SLOT(save()), actionCollection());
+ KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
+ KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+ KStdAction::save(this, TQ_SLOT(save()), actionCollection());
// set our XML-UI resource file
setXMLFile("%{APPNAMELC}_part.rc");
@@ -49,12 +49,12 @@ void %{APPNAME}Part::setReadWrite(bool rw)
// notify your internal widget of the read-write state
m_widget->setReadOnly(!rw);
if (rw)
- connect(m_widget, TQT_SIGNAL(textChanged()),
- this, TQT_SLOT(setModified()));
+ connect(m_widget, TQ_SIGNAL(textChanged()),
+ this, TQ_SLOT(setModified()));
else
{
- disconnect(m_widget, TQT_SIGNAL(textChanged()),
- this, TQT_SLOT(setModified()));
+ disconnect(m_widget, TQ_SIGNAL(textChanged()),
+ this, TQ_SLOT(setModified()));
}
ReadWritePart::setReadWrite(rw);
diff --git a/languages/cpp/app_templates/kpartplugin/plugin_app.cpp b/languages/cpp/app_templates/kpartplugin/plugin_app.cpp
index c395d983..ecda7fb0 100644
--- a/languages/cpp/app_templates/kpartplugin/plugin_app.cpp
+++ b/languages/cpp/app_templates/kpartplugin/plugin_app.cpp
@@ -14,7 +14,7 @@ Plugin%{APPNAME}::Plugin%{APPNAME}( TQObject* parent, const char* name )
// Instantiate all of your actions here. These will appear in
// Konqueror's menu and toolbars.
(void) new TDEAction( i18n("&Plugin Action"), "%{APPNAMELC}", 0,
- this, TQT_SLOT(slotAction()),
+ this, TQ_SLOT(slotAction()),
actionCollection(), "plugin_action" );
}
diff --git a/languages/cpp/app_templates/kscons_kxt/app.cpp b/languages/cpp/app_templates/kscons_kxt/app.cpp
index 00e1adea..44a90d53 100644
--- a/languages/cpp/app_templates/kscons_kxt/app.cpp
+++ b/languages/cpp/app_templates/kscons_kxt/app.cpp
@@ -48,10 +48,10 @@
setAutoSaveSettings();
// allow the view to change the statusbar and caption
- connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
- this, TQT_SLOT(changeStatusbar(const TQString&)));
- connect(m_view, TQT_SIGNAL(signalChangeCaption(const TQString&)),
- this, TQT_SLOT(changeCaption(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeStatusbar(const TQString&)),
+ this, TQ_SLOT(changeStatusbar(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeCaption(const TQString&)),
+ this, TQ_SLOT(changeCaption(const TQString&)));
showTipOnStart();
}
@@ -62,22 +62,22 @@
void %{APPNAME}::setupActions()
{
- KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
- KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+ KStdAction::openNew(this, TQ_SLOT(fileNew()), actionCollection());
+ KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
- m_toolbarAction = KStdAction::showToolbar(this, TQT_SLOT(optionsShowToolbar()), actionCollection());
- m_statusbarAction = KStdAction::showStatusbar(this, TQT_SLOT(optionsShowStatusbar()), actionCollection());
+ m_toolbarAction = KStdAction::showToolbar(this, TQ_SLOT(optionsShowToolbar()), actionCollection());
+ m_statusbarAction = KStdAction::showStatusbar(this, TQ_SLOT(optionsShowStatusbar()), actionCollection());
- KStdAction::tipOfDay( this, TQT_SLOT( showTip() ), actionCollection()
+ KStdAction::tipOfDay( this, TQ_SLOT( showTip() ), actionCollection()
)->setWhatsThis(i18n("This shows useful tips on the use of this application."));
- KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
- KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
- KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+ KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+ KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
+ KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
// custom menu and menu item - the slot is in the class %{APPNAME}View
TDEAction *custom = new TDEAction(i18n("Swi&tch Colors"), 0,
- m_view, TQT_SLOT(switchColors()),
+ m_view, TQ_SLOT(switchColors()),
actionCollection(), "switch_action");
createGUI();
@@ -140,7 +140,7 @@ void %{APPNAME}::optionsPreferences()
// to the names of the variables in the .kcfg file
TDEConfigDialog *dialog = new TDEConfigDialog(this, "settings", Settings::self(), KDialogBase::Swallow);
dialog->addPage(new Prefs(), i18n("General"), "package_settings");
- connect(dialog, TQT_SIGNAL(settingsChanged()), m_view, TQT_SLOT(settingsChanged()));
+ connect(dialog, TQ_SIGNAL(settingsChanged()), m_view, TQ_SLOT(settingsChanged()));
dialog->show();
}
diff --git a/languages/cpp/app_templates/kscons_tdemdi/app_part.cpp b/languages/cpp/app_templates/kscons_tdemdi/app_part.cpp
index cde31592..daa8b078 100644
--- a/languages/cpp/app_templates/kscons_tdemdi/app_part.cpp
+++ b/languages/cpp/app_templates/kscons_tdemdi/app_part.cpp
@@ -31,9 +31,9 @@ K_EXPORT_COMPONENT_FACTORY( lib%{APPNAMELC}part, %{APPNAMELC}PartFactory );
setWidget(m_widget);
// create our actions
- KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
- KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
- KStdAction::save(this, TQT_SLOT(save()), actionCollection());
+ KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
+ KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+ KStdAction::save(this, TQ_SLOT(save()), actionCollection());
// set our XML-UI resource file
setXMLFile("%{APPNAMELC}_part.rc");
@@ -63,12 +63,12 @@ void %{APPNAMELC}Part::setReadWrite(bool rw)
// notify your internal widget of the read-write state
m_widget->setReadOnly(!rw);
if (rw)
- connect(m_widget, TQT_SIGNAL(textChanged()),
- this, TQT_SLOT(setModified()));
+ connect(m_widget, TQ_SIGNAL(textChanged()),
+ this, TQ_SLOT(setModified()));
else
{
- disconnect(m_widget, TQT_SIGNAL(textChanged()),
- this, TQT_SLOT(setModified()));
+ disconnect(m_widget, TQ_SIGNAL(textChanged()),
+ this, TQ_SLOT(setModified()));
}
ReadWritePart::setReadWrite(rw);
diff --git a/languages/cpp/app_templates/kscons_tdemdi/apptdemdi.cpp b/languages/cpp/app_templates/kscons_tdemdi/apptdemdi.cpp
index c63cb223..51639f36 100644
--- a/languages/cpp/app_templates/kscons_tdemdi/apptdemdi.cpp
+++ b/languages/cpp/app_templates/kscons_tdemdi/apptdemdi.cpp
@@ -53,8 +53,8 @@
setStandardMDIMenuEnabled(false);
m_manager = new KParts::PartManager(this);
- connect(m_manager, TQT_SIGNAL(activePartChanged(KParts::Part*)),
- this, TQT_SLOT(createGUI(KParts::Part*)) );
+ connect(m_manager, TQ_SIGNAL(activePartChanged(KParts::Part*)),
+ this, TQ_SLOT(createGUI(KParts::Part*)) );
#if KDE_IS_VERSION(3, 3, 0)
setToolviewStyle( KMdi::TextAndIcon );
@@ -77,7 +77,7 @@
// and a status bar
statusBar()->show();
- connect( this, TQT_SIGNAL( viewActivated( KMdiChildView * ) ), this, TQT_SLOT( currentChanged( KMdiChildView * ) ) );
+ connect( this, TQ_SIGNAL( viewActivated( KMdiChildView * ) ), this, TQ_SLOT( currentChanged( KMdiChildView * ) ) );
m_console = new tdemdikonsole(this, "konsole");
m_console->setIcon( SmallIcon("konsole") );
@@ -92,7 +92,7 @@
but->setIconSet(SmallIcon("tab_remove"));
but->adjustSize();
but->hide();
- connect(but, TQT_SIGNAL(clicked()), actionCollection()->action( "file_close" ), TQT_SIGNAL(activated()));
+ connect(but, TQ_SIGNAL(clicked()), actionCollection()->action( "file_close" ), TQ_SIGNAL(activated()));
tabWidget()->setCornerWidget(but, TopRight);
}
#endif
@@ -124,22 +124,22 @@ void %{APPNAMELC}tdemdi::setupActions()
{
setXMLFile("%{APPNAMELC}_shell.rc");
- KStdAction::openNew(this, TQT_SLOT(slotFileNew()), actionCollection());
+ KStdAction::openNew(this, TQ_SLOT(slotFileNew()), actionCollection());
- KStdAction::tipOfDay( this, TQT_SLOT( showTip() ), actionCollection()
+ KStdAction::tipOfDay( this, TQ_SLOT( showTip() ), actionCollection()
)->setWhatsThis(i18n("This shows useful tips on the use of this application."));
- KStdAction::close(this, TQT_SLOT(slotFileClose()), actionCollection());
- KStdAction::quit(this, TQT_SLOT(slotFileQuit()), actionCollection());
+ KStdAction::close(this, TQ_SLOT(slotFileClose()), actionCollection());
+ KStdAction::quit(this, TQ_SLOT(slotFileQuit()), actionCollection());
- m_toolbarAction = KStdAction::showToolbar(this, TQT_SLOT(optionsShowToolbar()), actionCollection());
- m_statusbarAction = KStdAction::showStatusbar(this, TQT_SLOT(optionsShowStatusbar()), actionCollection());
+ m_toolbarAction = KStdAction::showToolbar(this, TQ_SLOT(optionsShowToolbar()), actionCollection());
+ m_statusbarAction = KStdAction::showStatusbar(this, TQ_SLOT(optionsShowStatusbar()), actionCollection());
- KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
- KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+ KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+ KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
TDEAction* action = KStdAction::configureToolbars(this,
- TQT_SLOT(optionsConfigureToolbars()), actionCollection());
+ TQ_SLOT(optionsConfigureToolbars()), actionCollection());
createGUI( NULL );
}
@@ -320,7 +320,7 @@ void %{APPNAMELC}tdemdi::optionsPreferences()
TDEConfigDialog *dialog = new TDEConfigDialog(this, "settings", Settings::self(), KDialogBase::Swallow);
dialog->addPage(new prefs(), i18n("General"), "package_settings");
- connect(dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(settingsChanged()));
+ connect(dialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(settingsChanged()));
dialog->show();
}
diff --git a/languages/cpp/app_templates/kscons_tdemdi/apptdemdiView.cpp b/languages/cpp/app_templates/kscons_tdemdi/apptdemdiView.cpp
index 1feb1b8b..24b1a974 100644
--- a/languages/cpp/app_templates/kscons_tdemdi/apptdemdiView.cpp
+++ b/languages/cpp/app_templates/kscons_tdemdi/apptdemdiView.cpp
@@ -39,7 +39,7 @@
part()->widget()->reparent( this, TQPoint(0, 0) );
layout->addWidget( part()->widget() );
- // connect( m_part, TQT_SIGNAL(stateChanged()), this, TQT_SLOT(updateCaption()) );
+ // connect( m_part, TQ_SIGNAL(stateChanged()), this, TQ_SLOT(updateCaption()) );
}
else
{
diff --git a/languages/cpp/app_templates/kscons_tdemdi/tdemdikonsole.cpp b/languages/cpp/app_templates/kscons_tdemdi/tdemdikonsole.cpp
index d4092b03..22c399ef 100644
--- a/languages/cpp/app_templates/kscons_tdemdi/tdemdikonsole.cpp
+++ b/languages/cpp/app_templates/kscons_tdemdi/tdemdikonsole.cpp
@@ -35,7 +35,7 @@ void tdemdikonsole::respawn()
((TQFrame*)m_part->widget())->setFrameStyle(TQFrame::Panel|TQFrame::Sunken);
m_haskonsole=true;
- connect( m_part, TQT_SIGNAL(destroyed()), this, TQT_SLOT(slotDestroyed()) );
+ connect( m_part, TQ_SIGNAL(destroyed()), this, TQ_SLOT(slotDestroyed()) );
m_part->widget()->show();
show();
diff --git a/languages/cpp/app_templates/kxt/app.cpp b/languages/cpp/app_templates/kxt/app.cpp
index ecdd5127..e9edb6d5 100644
--- a/languages/cpp/app_templates/kxt/app.cpp
+++ b/languages/cpp/app_templates/kxt/app.cpp
@@ -47,10 +47,10 @@
setAutoSaveSettings();
// allow the view to change the statusbar and caption
- connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
- this, TQT_SLOT(changeStatusbar(const TQString&)));
- connect(m_view, TQT_SIGNAL(signalChangeCaption(const TQString&)),
- this, TQT_SLOT(changeCaption(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeStatusbar(const TQString&)),
+ this, TQ_SLOT(changeStatusbar(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeCaption(const TQString&)),
+ this, TQ_SLOT(changeCaption(const TQString&)));
}
@@ -60,19 +60,19 @@
void %{APPNAMELC}::setupActions()
{
- KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
- KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+ KStdAction::openNew(this, TQ_SLOT(fileNew()), actionCollection());
+ KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
- m_toolbarAction = KStdAction::showToolbar(this, TQT_SLOT(optionsShowToolbar()), actionCollection());
- m_statusbarAction = KStdAction::showStatusbar(this, TQT_SLOT(optionsShowStatusbar()), actionCollection());
+ m_toolbarAction = KStdAction::showToolbar(this, TQ_SLOT(optionsShowToolbar()), actionCollection());
+ m_statusbarAction = KStdAction::showStatusbar(this, TQ_SLOT(optionsShowStatusbar()), actionCollection());
- KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
- KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
- KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+ KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+ KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
+ KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
// custom menu and menu item - the slot is in the class %{APPNAMELC}View
TDEAction *custom = new TDEAction(i18n("Swi&tch Colors"), 0,
- m_view, TQT_SLOT(switchColors()),
+ m_view, TQ_SLOT(switchColors()),
actionCollection(), "switch_action");
createGUI();
@@ -135,7 +135,7 @@ void %{APPNAMELC}::optionsPreferences()
// to the names of the variables in the .kcfg file
TDEConfigDialog *dialog = new TDEConfigDialog(this, "settings", Settings::self(), KDialogBase::Swallow);
dialog->addPage(new Prefs(), i18n("General"), "package_settings");
- connect(dialog, TQT_SIGNAL(settingsChanged()), m_view, TQT_SLOT(settingsChanged()));
+ connect(dialog, TQ_SIGNAL(settingsChanged()), m_view, TQ_SLOT(settingsChanged()));
dialog->show();
}
diff --git a/languages/cpp/app_templates/noatunui/plugin_impl.cpp b/languages/cpp/app_templates/noatunui/plugin_impl.cpp
index 89ad08e5..a0c0d0ee 100644
--- a/languages/cpp/app_templates/noatunui/plugin_impl.cpp
+++ b/languages/cpp/app_templates/noatunui/plugin_impl.cpp
@@ -33,45 +33,45 @@
mBack=new TQPushButton(this);
mBack->setFixedSize(buttonSize,buttonSize);
mBack->setPixmap(BarIcon("noatunback"));
- connect(mBack, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(back()));
+ connect(mBack, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(back()));
TQToolTip::add(mBack,i18n("Back"));
mStop=new TQPushButton(this);
mStop->setFixedSize(buttonSize,buttonSize);
mStop->setPixmap(BarIcon("noatunstop"));
- connect(mStop, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(stop()));
+ connect(mStop, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(stop()));
TQToolTip::add(mStop, i18n("Stop"));
mPlay=new TQPushButton(this);
mPlay->setToggleButton(true);
mPlay->setFixedSize(buttonSize,buttonSize);
mPlay->setPixmap(BarIcon("noatunplay"));
- connect(mPlay, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(playpause()));
+ connect(mPlay, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(playpause()));
TQToolTip::add(mPlay, i18n("Play"));
mForward=new TQPushButton(this);
mForward->setFixedSize(buttonSize,buttonSize);
mForward->setPixmap(BarIcon("noatunforward"));
- connect(mForward, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(forward()));
+ connect(mForward, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(forward()));
TQToolTip::add(mForward, i18n("Forward"));
mPlaylist=new TQPushButton(this);
mPlaylist->setToggleButton(true);
mPlaylist->setFixedSize(buttonSize,buttonSize);
mPlaylist->setPixmap(BarIcon("noatunplaylist"));
- connect(mPlaylist, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(toggleListView()));
+ connect(mPlaylist, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(toggleListView()));
TQToolTip::add(mPlaylist, i18n("Playlist"));
mLoop=new TQPushButton(this);
mLoop->setFixedSize(buttonSize,buttonSize);
mLoop->setPixmap(BarIcon("noatunloopnone"));
- connect(mLoop, TQT_SIGNAL(clicked()), napp->player(), TQT_SLOT(loop()));
+ connect(mLoop, TQ_SIGNAL(clicked()), napp->player(), TQ_SLOT(loop()));
TQToolTip::add(mLoop, i18n("Change loop style"));
mPopup=new TQPushButton(this);
mPopup->setFixedSize(buttonSize,buttonSize);
mPopup->setPixmap(BarIcon("noatun"));
- connect(mPopup, TQT_SIGNAL(clicked()), TQT_SLOT(popup()));
+ connect(mPopup, TQ_SIGNAL(clicked()), TQ_SLOT(popup()));
mVolume=new L33tSlider(0,100,10,0,TQt::Horizontal, this);
@@ -98,30 +98,30 @@
statusBar()->message(i18n("No File Loaded"));
statusBar()->insertItem("--:--/--:--", 1, 0, true);
- connect(napp, TQT_SIGNAL(hideYourself()), this, TQT_SLOT(hide()) );
- connect(napp, TQT_SIGNAL(showYourself()), this, TQT_SLOT(show()) );
+ connect(napp, TQ_SIGNAL(hideYourself()), this, TQ_SLOT(hide()) );
+ connect(napp, TQ_SIGNAL(showYourself()), this, TQ_SLOT(show()) );
- connect(napp->player(), TQT_SIGNAL(playing()), this, TQT_SLOT(slotPlaying()));
- connect(napp->player(), TQT_SIGNAL(stopped()), this, TQT_SLOT(slotStopped()));
- connect(napp->player(), TQT_SIGNAL(paused()), this, TQT_SLOT(slotPaused()));
+ connect(napp->player(), TQ_SIGNAL(playing()), this, TQ_SLOT(slotPlaying()));
+ connect(napp->player(), TQ_SIGNAL(stopped()), this, TQ_SLOT(slotStopped()));
+ connect(napp->player(), TQ_SIGNAL(paused()), this, TQ_SLOT(slotPaused()));
napp->player()->handleButtons();
- connect(napp->player(), TQT_SIGNAL(timeout()), this, TQT_SLOT(slotTimeout()));
- connect(napp->player(), TQT_SIGNAL(loopTypeChange(int)), this, TQT_SLOT(changeLoopType(int)));
+ connect(napp->player(), TQ_SIGNAL(timeout()), this, TQ_SLOT(slotTimeout()));
+ connect(napp->player(), TQ_SIGNAL(loopTypeChange(int)), this, TQ_SLOT(changeLoopType(int)));
/* This skipToWrapper is needed to pass milliseconds to Player() as everybody
* below the GUI is based on milliseconds instead of some unprecise thingy
* like seconds or mille */
- connect(seeker(), TQT_SIGNAL(userChanged(int)), this, TQT_SLOT(skipToWrapper(int)));
- connect(this, TQT_SIGNAL(skipTo(int)), napp->player(), TQT_SLOT(skipTo(int)));
- connect(seeker(), TQT_SIGNAL(sliderMoved(int)), TQT_SLOT(sliderMoved(int)));
+ connect(seeker(), TQ_SIGNAL(userChanged(int)), this, TQ_SLOT(skipToWrapper(int)));
+ connect(this, TQ_SIGNAL(skipTo(int)), napp->player(), TQ_SLOT(skipTo(int)));
+ connect(seeker(), TQ_SIGNAL(sliderMoved(int)), TQ_SLOT(sliderMoved(int)));
- connect(mVolume, TQT_SIGNAL(sliderMoved(int)), napp->player(), TQT_SLOT(setVolume(int)));
- connect(mVolume, TQT_SIGNAL(userChanged(int)), napp->player(), TQT_SLOT(setVolume(int)));
+ connect(mVolume, TQ_SIGNAL(sliderMoved(int)), napp->player(), TQ_SLOT(setVolume(int)));
+ connect(mVolume, TQ_SIGNAL(userChanged(int)), napp->player(), TQ_SLOT(setVolume(int)));
- connect(napp->player(), TQT_SIGNAL(playlistShown()), TQT_SLOT(playlistShown()));
- connect(napp->player(), TQT_SIGNAL(playlistHidden()), TQT_SLOT(playlistHidden()));
+ connect(napp->player(), TQ_SIGNAL(playlistShown()), TQ_SLOT(playlistShown()));
+ connect(napp->player(), TQ_SIGNAL(playlistHidden()), TQ_SLOT(playlistHidden()));
// Event Filter for the RMB
for (TQPtrListIterator<TQObject> i(*children()); i.current(); ++i)
diff --git a/languages/cpp/app_templates/opieapp/example.cpp b/languages/cpp/app_templates/opieapp/example.cpp
index 6a0d616e..f0be7179 100644
--- a/languages/cpp/app_templates/opieapp/example.cpp
+++ b/languages/cpp/app_templates/opieapp/example.cpp
@@ -12,7 +12,7 @@ OPIE_EXPORT_APP( %{APPNAME}Factory )
%{APPNAME}::%{APPNAME}( TQWidget* parent, const char* name, WFlags fl )
: %{APPNAME}Base( parent, name, fl )
{
- connect(quit, TQT_SIGNAL(clicked()), this, TQT_SLOT(goodBye()));
+ connect(quit, TQ_SIGNAL(clicked()), this, TQ_SLOT(goodBye()));
}
/*
diff --git a/languages/cpp/app_templates/opieinput/simpleimpl.cpp b/languages/cpp/app_templates/opieinput/simpleimpl.cpp
index a77f413b..dd3475e1 100644
--- a/languages/cpp/app_templates/opieinput/simpleimpl.cpp
+++ b/languages/cpp/app_templates/opieinput/simpleimpl.cpp
@@ -11,33 +11,33 @@
: TQHBox(par, "name", fl )
{
TQCheckBox *box1 = new TQCheckBox(tr("Alt"),this);
- connect(box1,TQT_SIGNAL(toggled(bool)),
- this,TQT_SLOT(slotAlt(bool)));
+ connect(box1,TQ_SIGNAL(toggled(bool)),
+ this,TQ_SLOT(slotAlt(bool)));
m_alt = box1;
box1 = new TQCheckBox(tr("Shift"),this );
- connect(box1,TQT_SIGNAL(toggled(bool)),
- this,TQT_SLOT(slotShift(bool)));
+ connect(box1,TQ_SIGNAL(toggled(bool)),
+ this,TQ_SLOT(slotShift(bool)));
m_shi = box1;
box1 = new TQCheckBox(tr("Ctrl","Control Shortcut on keyboard"),this );
- connect(box1,TQT_SIGNAL(toggled(bool)),
- this,TQT_SLOT(slotCtrl(bool)));
+ connect(box1,TQ_SIGNAL(toggled(bool)),
+ this,TQ_SLOT(slotCtrl(bool)));
m_ctrl = box1;
TQSignalMapper *map = new TQSignalMapper(this);
TQPushButton *btn = new TQPushButton("a",this);
map->setMapping(btn,0);
- connect(btn,TQT_SIGNAL(clicked()),map,TQT_SLOT(map()));
+ connect(btn,TQ_SIGNAL(clicked()),map,TQ_SLOT(map()));
btn = new TQPushButton("b",this);
map->setMapping(btn,1);
- connect(btn,TQT_SIGNAL(clicked()),map,TQT_SLOT(map()));
+ connect(btn,TQ_SIGNAL(clicked()),map,TQ_SLOT(map()));
btn = new TQPushButton("c",this);
map->setMapping(btn,2);
- connect(btn,TQT_SIGNAL(clicked()),map,TQT_SLOT(map()));
+ connect(btn,TQ_SIGNAL(clicked()),map,TQ_SLOT(map()));
- connect(map,TQT_SIGNAL(mapped(int)),
- this,TQT_SLOT(slotKey(int)));
+ connect(map,TQ_SIGNAL(mapped(int)),
+ this,TQ_SLOT(slotKey(int)));
resetState();
}
@@ -130,7 +130,7 @@ TQString %{APPNAME}Impl::name()
void %{APPNAME}Impl::onKeyPress( TQObject *receiver, const char *slot )
{
if ( m_pickboard )
- TQObject::connect( m_pickboard, TQT_SIGNAL(key(ushort,ushort,ushort,bool,bool)), receiver, slot );
+ TQObject::connect( m_pickboard, TQ_SIGNAL(key(ushort,ushort,ushort,bool,bool)), receiver, slot );
}
#ifndef TQT_NO_COMPONENT
diff --git a/languages/cpp/app_templates/opietoday/examplepluginwidget.cpp b/languages/cpp/app_templates/opietoday/examplepluginwidget.cpp
index 2f491481..fdbbf4dd 100644
--- a/languages/cpp/app_templates/opietoday/examplepluginwidget.cpp
+++ b/languages/cpp/app_templates/opietoday/examplepluginwidget.cpp
@@ -17,7 +17,7 @@
// that should be triggered when clicked are defined in slotClicked()
// of course also normal widgets can be used.
m_exampleLabel = new OClickableLabel( this );
- connect( m_exampleLabel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotClicked() ) );
+ connect( m_exampleLabel, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotClicked() ) );
if ( m_layout ) {
delete m_layout;
diff --git a/languages/cpp/app_templates/qmakeapp/main.cpp b/languages/cpp/app_templates/qmakeapp/main.cpp
index 8938adc5..ba45c728 100644
--- a/languages/cpp/app_templates/qmakeapp/main.cpp
+++ b/languages/cpp/app_templates/qmakeapp/main.cpp
@@ -8,6 +8,6 @@ int main( int argc, char ** argv ) {
%{APPNAME} * mw = new %{APPNAME}();
mw->setCaption( "%{APPNAME}" );
mw->show();
- a.connect( &a, TQT_SIGNAL(lastWindowClosed()), &a, TQT_SLOT(quit()) );
+ a.connect( &a, TQ_SIGNAL(lastWindowClosed()), &a, TQ_SLOT(quit()) );
return a.exec();
}
diff --git a/languages/cpp/app_templates/qmakeapp/qmakeapp.cpp b/languages/cpp/app_templates/qmakeapp/qmakeapp.cpp
index 39b6e5af..8ce81310 100644
--- a/languages/cpp/app_templates/qmakeapp/qmakeapp.cpp
+++ b/languages/cpp/app_templates/qmakeapp/qmakeapp.cpp
@@ -37,17 +37,17 @@
openIcon = TQPixmap( fileopen );
TQToolButton * fileOpen
= new TQToolButton( openIcon, tr("Open File"), TQString(),
- this, TQT_SLOT(choose()), fileTools, "open file" );
+ this, TQ_SLOT(choose()), fileTools, "open file" );
saveIcon = TQPixmap( filesave );
TQToolButton * fileSave
= new TQToolButton( saveIcon, tr("Save File"), TQString(),
- this, TQT_SLOT(save()), fileTools, "save file" );
+ this, TQ_SLOT(save()), fileTools, "save file" );
printIcon = TQPixmap( fileprint );
TQToolButton * filePrint
= new TQToolButton( printIcon, tr("Print File"), TQString(),
- this, TQT_SLOT(print()), fileTools, "print file" );
+ this, TQ_SLOT(print()), fileTools, "print file" );
(void)TQWhatsThis::whatsThisButton( fileTools );
@@ -79,41 +79,41 @@
menuBar()->insertItem( tr("&File"), file );
- file->insertItem( tr("&New"), this, TQT_SLOT(newDoc()), CTRL+Key_N );
+ file->insertItem( tr("&New"), this, TQ_SLOT(newDoc()), CTRL+Key_N );
int id;
id = file->insertItem( openIcon, tr("&Open..."),
- this, TQT_SLOT(choose()), CTRL+Key_O );
+ this, TQ_SLOT(choose()), CTRL+Key_O );
file->setWhatsThis( id, fileOpenText );
id = file->insertItem( saveIcon, tr("&Save"),
- this, TQT_SLOT(save()), CTRL+Key_S );
+ this, TQ_SLOT(save()), CTRL+Key_S );
file->setWhatsThis( id, fileSaveText );
- id = file->insertItem( tr("Save &As..."), this, TQT_SLOT(saveAs()) );
+ id = file->insertItem( tr("Save &As..."), this, TQ_SLOT(saveAs()) );
file->setWhatsThis( id, fileSaveText );
file->insertSeparator();
id = file->insertItem( printIcon, tr("&Print..."),
- this, TQT_SLOT(print()), CTRL+Key_P );
+ this, TQ_SLOT(print()), CTRL+Key_P );
file->setWhatsThis( id, filePrintText );
file->insertSeparator();
- file->insertItem( tr("&Close"), this, TQT_SLOT(close()), CTRL+Key_W );
+ file->insertItem( tr("&Close"), this, TQ_SLOT(close()), CTRL+Key_W );
- file->insertItem( tr("&Quit"), tqApp, TQT_SLOT( closeAllWindows() ), CTRL+Key_Q );
+ file->insertItem( tr("&Quit"), tqApp, TQ_SLOT( closeAllWindows() ), CTRL+Key_Q );
menuBar()->insertSeparator();
TQPopupMenu * help = new TQPopupMenu( this );
menuBar()->insertItem( tr("&Help"), help );
- help->insertItem( tr("&About"), this, TQT_SLOT(about()), Key_F1 );
- help->insertItem( tr("About &TQt"), this, TQT_SLOT(aboutTQt()) );
+ help->insertItem( tr("&About"), this, TQ_SLOT(about()), Key_F1 );
+ help->insertItem( tr("About &TQt"), this, TQ_SLOT(aboutTQt()) );
help->insertSeparator();
- help->insertItem( tr("What's &This"), this, TQT_SLOT(whatsThis()), SHIFT+Key_F1 );
+ help->insertItem( tr("What's &This"), this, TQ_SLOT(whatsThis()), SHIFT+Key_F1 );
e = new TQTextEdit( this, "editor" );
e->setFocus();
diff --git a/languages/cpp/app_templates/qtopiaapp/example.cpp b/languages/cpp/app_templates/qtopiaapp/example.cpp
index d68f6c6d..f03ea5c3 100644
--- a/languages/cpp/app_templates/qtopiaapp/example.cpp
+++ b/languages/cpp/app_templates/qtopiaapp/example.cpp
@@ -9,7 +9,7 @@
%{APPNAME}::%{APPNAME}( TQWidget* parent, const char* name, WFlags fl )
: %{APPNAME}Base( parent, name, fl )
{
- connect(quit, TQT_SIGNAL(clicked()), this, TQT_SLOT(goodBye()));
+ connect(quit, TQ_SIGNAL(clicked()), this, TQ_SLOT(goodBye()));
}
/*
diff --git a/languages/cpp/app_templates/tdeconfig35/app.cpp b/languages/cpp/app_templates/tdeconfig35/app.cpp
index 1aab14b5..ce638d20 100644
--- a/languages/cpp/app_templates/tdeconfig35/app.cpp
+++ b/languages/cpp/app_templates/tdeconfig35/app.cpp
@@ -34,10 +34,10 @@
setAutoSaveSettings();
// allow the view to change the statusbar and caption
- connect(m_view, TQT_SIGNAL(signalChangeStatusbar(const TQString&)),
- this, TQT_SLOT(changeStatusbar(const TQString&)));
- connect(m_view, TQT_SIGNAL(signalChangeCaption(const TQString&)),
- this, TQT_SLOT(changeCaption(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeStatusbar(const TQString&)),
+ this, TQ_SLOT(changeStatusbar(const TQString&)));
+ connect(m_view, TQ_SIGNAL(signalChangeCaption(const TQString&)),
+ this, TQ_SLOT(changeCaption(const TQString&)));
}
@@ -47,14 +47,14 @@
void %{APPNAMELC}::setupActions()
{
- KStdAction::openNew(this, TQT_SLOT(fileNew()), actionCollection());
- KStdAction::quit(kapp, TQT_SLOT(quit()), actionCollection());
+ KStdAction::openNew(this, TQ_SLOT(fileNew()), actionCollection());
+ KStdAction::quit(kapp, TQ_SLOT(quit()), actionCollection());
- KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
+ KStdAction::preferences(this, TQ_SLOT(optionsPreferences()), actionCollection());
// custom menu and menu item
TDEAction *custom = new TDEAction(i18n("Swi&tch Colors"), 0,
- m_view, TQT_SLOT(switchColors()),
+ m_view, TQ_SLOT(switchColors()),
actionCollection(), "switch_action");
setupGUI();
@@ -75,7 +75,7 @@ void %{APPNAMELC}::optionsPreferences()
// to the names of the variables in the .kcfg file
TDEConfigDialog *dialog = new TDEConfigDialog(this, "settings", Settings::self(), KDialogBase::Swallow);
dialog->addPage(new Prefs(), i18n("General"), "package_settings");
- connect(dialog, TQT_SIGNAL(settingsChanged()), m_view, TQT_SLOT(settingsChanged()));
+ connect(dialog, TQ_SIGNAL(settingsChanged()), m_view, TQ_SLOT(settingsChanged()));
dialog->show();
}
diff --git a/languages/cpp/app_templates/tdescreensaver/tdescreensaver.cpp b/languages/cpp/app_templates/tdescreensaver/tdescreensaver.cpp
index 0d2bf1ff..168cd8c4 100644
--- a/languages/cpp/app_templates/tdescreensaver/tdescreensaver.cpp
+++ b/languages/cpp/app_templates/tdescreensaver/tdescreensaver.cpp
@@ -38,10 +38,10 @@ extern "C"
{
/// @todo
//Connect your signals and slots here to configure the screen saver.
- connect( OkayPushButton, TQT_SIGNAL( released() ),
- TQT_SLOT( slotOkPressed() ) );
- connect( CancelPushButton, TQT_SIGNAL( released() ),
- TQT_SLOT( slotCancelPressed() ) );
+ connect( OkayPushButton, TQ_SIGNAL( released() ),
+ TQ_SLOT( slotOkPressed() ) );
+ connect( CancelPushButton, TQ_SIGNAL( released() ),
+ TQ_SLOT( slotCancelPressed() ) );
}
diff --git a/languages/cpp/app_templates/kateplugin2/plugin_app.cpp b/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
index 8845fae3..19b31c71 100644
--- a/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
+++ b/languages/cpp/app_templates/kateplugin2/plugin_app.cpp
@@ -59,7 +59,7 @@ void KatePlugin%{APPNAME}::addView(Kate::MainWindow *win)
PluginView *view = new PluginView ();
(void) new TDEAction ( i18n("Insert Hello World"), 0, this,
- TQT_SLOT( slotInsertHello() ), view->actionCollection(),
+ TQ_SLOT( slotInsertHello() ), view->actionCollection(),
"edit_insert_%{APPNAMELC}" );
view->setInstance (new TDEInstance("kate"));
@@ -94,7 +94,7 @@ Kate::PluginConfigPage* KatePlugin%{APPNAME}::configPage (uint, TQWidget *w, con
{
%{APPNAME}ConfigPage* p = new %{APPNAME}ConfigPage(this, w);
initConfigPage( p );
- connect( p, TQT_SIGNAL(configPageApplyRequest(%{APPNAME}ConfigPage*)), this, TQT_SLOT(slotApplyConfig(%{APPNAME}ConfigPage*)) );
+ connect( p, TQ_SIGNAL(configPageApplyRequest(%{APPNAME}ConfigPage*)), this, TQ_SLOT(slotApplyConfig(%{APPNAME}ConfigPage*)) );
return (Kate::PluginConfigPage*)p;
}
@@ -124,7 +124,7 @@ void KatePlugin%{APPNAME}::slotApplyConfig( %{APPNAME}ConfigPage* p )
lo->addWidget(lab);
// TODO: add connection to emit TQT_SLOT( changed() )
}
%{APPNAME}ConfigPage::~%{APPNAME}ConfigPage()
@@ -124,7 +124,7 @@ void KatePlugin%{APPNAME}::slotApplyConfig( %{APPNAME}ConfigPage* p )
lo->addWidget(lab);
- // TODO: add connection to emit TQT_SLOT( changed() )
+ // TODO: add connection to emit TQ_SLOT( changed() )
}
%{APPNAME}ConfigPage::~%{APPNAME}ConfigPage()